<?php
/**
 * @package Responsive Content Slider
 * @copyright 2022 ComponentGenerator.com
 * @author 2022 ComponentGenerator(mail@componentgenerator.com)
 * @license GNU General Public License version 2 or later
 * @description Slide HTML content or images with the Responsive Content Slider
 */

namespace Joomla\Module\ResponsiveContentSlider\Site\Helper;

// No direct access
use Joomla\CMS\Uri\Uri;

defined( '_JEXEC' ) or die( 'Restricted access' );

/**
 * Class
 */
class ResponsiveContentSliderHelper
{
    /**
     * Method to get the images
     *
     * @return	array	$data	An array with the images
     */
    public static function getImages($params, $imagesToLoad): array
    {
        $allParams = [
            'path', 'title', 'url', 'external_url', 'content'
        ];

        if ((string)$params->get('slide_type') === 'images') {
            $requiredParams = [
                'path'
            ];
        } else {
            $requiredParams = [
                'content'
            ];
        }

        $images = [];
        for ($i = 1; $i <= $imagesToLoad; $i++) {
            // Get the image params
            $imageParams = self::imageParams($allParams, $requiredParams, $params, $i);

            if (isset($imageParams['path']) && (string)$imageParams['path'] !== '') {
                $imageParams['path'] = Uri::root() . $imageParams['path'];
            }

            // If some params were missing for the image
            if (!$imageParams)
            {
                // Then don't add the image
                continue;
            }

            $images[$i - 1] = $imageParams;
        }

        return $images;
    }

    /**
     * Method to get the image params
     *
     * @param	array		$requiredParams		The keys of the required params for the image
     * @params	JRegistry	$params				The params object from which the image params should be fetched
     * @param	int			$imageNumber		The image number
     *
     * @return	array/bool						Returns an array with the image params on success, otherwise false
     */
    private static function imageParams($allParams, $requiredParams, $params, $imageNumber)
    {
        $imageParams = array();

        $requiredParamsDefined = true;
        foreach ($requiredParams as $requiredParam)
        {
            $imageParam = $params->get('slide_' . $requiredParam . '_' . $imageNumber);
            if (!$imageParam)
            {
                $requiredParamsDefined = false;
            }
        }

        // If all required params were defined
        if ($requiredParamsDefined)
        {
            // Load the params for the image
            foreach ($allParams as $param)
            {
                $imageParams[$param] = $params->get('slide_' . $param . '_' . $imageNumber);
            }

            return $imageParams;
        }

        return $requiredParamsDefined;
    }
}
